/// Package import
import 'package:flutter/material.dart';
import 'package:intl/intl.dart';

/// Chart import
import 'package:syncfusion_flutter_charts/charts.dart';

void main() => runApp(const TrackballBuilderTesting());

class TrackballBuilderTesting extends StatelessWidget {
  const TrackballBuilderTesting({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      theme: ThemeData(
        primarySwatch: Colors.blue,
      ),
      home: const TrackballBuilder(),
    );
  }
}

/// Renders the chart with trackball builder.
class TrackballBuilder extends StatefulWidget {
  /// Creates the chart with trackball builder.
  const TrackballBuilder({Key? key}) : super(key: key);

  @override
  _TrackballBuilderState createState() => _TrackballBuilderState();
}

/// State class of the chart with trackball builder.
class _TrackballBuilderState extends State<TrackballBuilder> {
  _TrackballBuilderState();

  @override
  Widget build(BuildContext context) {
    return Scaffold(
        appBar: AppBar(),
        body: SfCartesianChart(
          primaryXAxis: DateTimeAxis(
            dateFormat: DateFormat.yMd(),
          ),
          primaryYAxis: NumericAxis(
              minimum: 20,
              axisLine: const AxisLine(width: 0),
              majorTickLines: const MajorTickLines(width: 0)),
          trackballBehavior: TrackballBehavior(
              enable: true,
              activationMode: ActivationMode.singleTap,
              builder:
                  (BuildContext context, TrackballDetails trackballDetails) {
                return Container(
                    color: Colors.grey,
                    width: 300,
                    child: const Text(
                        'Text to test the trackball builder in chart'));
              }),
          series: <ChartSeries<ChartSampleData, dynamic>>[
            SplineAreaSeries<ChartSampleData, dynamic>(
                dataSource: <ChartSampleData>[
                  ChartSampleData(
                    y: 45,
                    x: DateTime(2022, 4, 15),
                  ),
                  ChartSampleData(
                    y: 60,
                    x: DateTime(2022, 4, 16),
                  ),
                  ChartSampleData(
                    y: 51,
                    x: DateTime(2022, 4, 17),
                  ),
                  ChartSampleData(
                    y: 66,
                    x: DateTime(2022, 4, 18),
                  ),
                  ChartSampleData(
                    y: 44,
                    x: DateTime(2022, 4, 19),
                  ),
                  ChartSampleData(
                    y: 42,
                    x: DateTime(2022, 4, 20),
                  ),
                  ChartSampleData(
                    y: 40,
                    x: DateTime(2022, 4, 21),
                  ),
                  ChartSampleData(
                    y: 55,
                    x: DateTime(2022, 4, 22),
                  ),
                ],
                xValueMapper: (ChartSampleData sales, _) => sales.x,
                yValueMapper: (ChartSampleData sales, _) => sales.y,
                markerSettings: const MarkerSettings(isVisible: true)),
          ],
        ));
  }
}

/// Chart sample data
class ChartSampleData {
  /// Holds the datapoint values like x, y.
  ChartSampleData({this.y, this.x});

  /// Holds x value of the datapoint
  final DateTime? x;

  /// Holds y value of the datapoint
  final num? y;
}
